==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ToolActionLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionLabelDescription } from "./ToolActionLabelDescription";
/**
 * @hidden
 */
var ToolActionLabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionLabelDescriptionMetadata, _super);
    function ToolActionLabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionLabelDescriptionMetadata.b = function (a) {
        if (ToolActionLabelDescriptionMetadata.a == null) {
            ToolActionLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionLabelDescriptionMetadata.c(ToolActionLabelDescriptionMetadata.a);
        }
        if (a.j(ToolActionLabelDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionLabelDescriptionMetadata.a);
    };
    ToolActionLabelDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionLabelDescriptionMetadata.d = function (a) {
        ToolActionLabelDescriptionMetadata.b(a);
        a.aa("ToolActionLabel", function () { return new ToolActionLabelDescription(); });
        a.z("ToolActionLabel", ToolActionLabelDescriptionMetadata.a);
    };
    ToolActionLabelDescriptionMetadata.$t = markType(ToolActionLabelDescriptionMetadata, 'ToolActionLabelDescriptionMetadata');
    ToolActionLabelDescriptionMetadata.a = null;
    return ToolActionLabelDescriptionMetadata;
}(Base));
export { ToolActionLabelDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ToolActionLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionLabelDescription } from "./ToolActionLabelDescription";
/**
 * @hidden
 */
var ToolActionLabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionLabelDescriptionMetadata, _super);
    function ToolActionLabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionLabelDescriptionMetadata.b = function (a) {
        if (ToolActionLabelDescriptionMetadata.a == null) {
            ToolActionLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionLabelDescriptionMetadata.c(ToolActionLabelDescriptionMetadata.a);
        }
        if (a.k(ToolActionLabelDescriptionMetadata.a)) {
            return;
        }
        a.aa(ToolActionLabelDescriptionMetadata.a);
    };
    ToolActionLabelDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionLabelDescriptionMetadata.d = function (a) {
        ToolActionLabelDescriptionMetadata.b(a);
        a.ac("ToolActionLabel", function () { return new ToolActionLabelDescription(); });
        a.ab("ToolActionLabel", ToolActionLabelDescriptionMetadata.a);
    };
    ToolActionLabelDescriptionMetadata.$t = markType(ToolActionLabelDescriptionMetadata, 'ToolActionLabelDescriptionMetadata');
    ToolActionLabelDescriptionMetadata.a = null;
    return ToolActionLabelDescriptionMetadata;
}(Base));
export { ToolActionLabelDescriptionMetadata };
